@@ -4,28 +4,24 @@ from __future__ import annotations
 import copy
 import logging
 import os
-import pathlib
-import subprocess
 import sys
-from argparse import Namespace
-from collections import OrderedDict, defaultdict
+from collections import defaultdict
 from contextlib import contextmanager
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import TYPE_CHECKING, Any, Iterator, cast
+from typing import TYPE_CHECKING, Any, cast
 
+import pathspec
 import wcmatch.pathlib
-from wcmatch.wcmatch import RECURSIVE, WcMatch
+import wcmatch.wcmatch
 from yaml.error import YAMLError
 
-from ansiblelint.config import BASE_KINDS, options
-from ansiblelint.constants import GIT_CMD, FileType, States
+from ansiblelint.config import ANSIBLE_OWNED_KINDS, BASE_KINDS, Options, options
+from ansiblelint.constants import CONFIG_FILENAMES, FileType, States
 
 if TYPE_CHECKING:
-    # https://github.com/PyCQA/pylint/issues/3979
-    BasePathLike = os.PathLike[Any]  # pylint: disable=unsubscriptable-object
-else:
-    BasePathLike = os.PathLike
+    from collections.abc import Iterator, Sequence
+
 
 _logger = logging.getLogger(__package__)
 
@@ -33,10 +29,8 @@ _logger = logging.getLogger(__package__)
 def abspath(path: str, base_dir: str) -> str:
     """Make relative path absolute relative to given directory.
 
-    Args:
-       path (str): the path to make absolute
-       base_dir (str): the directory from which make \
-                       relative paths absolute
+    path (str): the path to make absolute
+    base_dir (str): the directory from which make relative paths absolute.
     """
     if not os.path.isabs(path):
         # Don't use abspath as it assumes path is relative to cwd.
@@ -46,9 +40,8 @@ def abspath(path: str, base_dir: str) -> str:
     return os.path.normpath(path)
 
 
-def normpath(path: str | BasePathLike) -> str:
-    """
-    Normalize a path in order to provide a more consistent output.
+def normpath(path: str | Path) -> str:
+    """Normalize a path in order to provide a more consistent output.
 
     Currently it generates a relative path but in the future we may want to
     make this user configurable.
@@ -81,7 +74,7 @@ def is_relative_to(path: Path, *other: Any) -> bool:
         return False
 
 
-def normpath_path(path: str | BasePathLike) -> Path:
+def normpath_path(path: str | Path) -> Path:
     """Normalize a path in order to provide a more consistent output.
 
     - Any symlinks are resolved.
@@ -107,9 +100,9 @@ def normpath_path(path: str | BasePathLike) -> Path:
 
 
 @contextmanager
-def cwd(path: str | BasePathLike) -> Iterator[None]:
+def cwd(path: Path) -> Iterator[None]:
     """Context manager for temporary changing current working directory."""
-    old_pwd = os.getcwd()
+    old_pwd = Path.cwd()
     os.chdir(path)
     try:
         yield
@@ -132,7 +125,7 @@ def expand_paths_vars(paths: list[str]) -> list[str]:
     return paths
 
 
-def kind_from_path(path: Path, base: bool = False) -> FileType:
+def kind_from_path(path: Path, *, base: bool = False) -> FileType:
     """Determine the file kind based on its name.
 
     When called with base=True, it will return the base file type instead
@@ -152,14 +145,22 @@ def kind_from_path(path: Path, base: bool = False) -> FileType:
                     | wcmatch.pathlib.DOTGLOB
                 ),
             ):
-                return str(k)  # type: ignore
+                return str(k)  # type: ignore[return-value]
 
     if base:
         # Unknown base file type is default
         return ""
 
     if path.is_dir():
-        return "role"
+        known_role_subfolders = ("tasks", "meta", "vars", "defaults", "handlers")
+        for filename in known_role_subfolders:
+            if (path / filename).is_dir():
+                return "role"
+        _logger.debug(
+            "Folder `%s` does not look like a role due to missing any of the common subfolders such: %s.",
+            path,
+            ", ".join(known_role_subfolders),
+        )
 
     if str(path) == "/dev/stdin":
         return "playbook"
@@ -178,20 +179,27 @@ class Lintable:
     When symlinks are given, they will always be resolved to their target.
     """
 
+    # pylint: disable=too-many-arguments
     def __init__(
         self,
         name: str | Path,
         content: str | None = None,
         kind: FileType | None = None,
         base_kind: str = "",
+        parent: Lintable | None = None,
     ):
         """Create a Lintable instance."""
         self.dir: str = ""
         self.kind: FileType | None = None
         self.stop_processing = False  # Set to stop other rules from running
-        self._data: Any = States.NOT_LOADED
+        self.state: Any = States.NOT_LOADED
         self.line_skips: dict[int, set[str]] = defaultdict(set)
         self.exc: Exception | None = None  # Stores data loading exceptions
+        self.parent = parent
+        self.explicit = False  # Indicates if the file was explicitly provided or was indirectly included.
+        self.line_offset = (
+            0  # Amount to offset line numbers by to get accurate position
+        )
 
         if isinstance(name, str):
             name = Path(name)
@@ -200,7 +208,9 @@ class Lintable:
         if is_relative:
             name = name.relative_to(name.cwd())
         name = normpath_path(name)
-        self.path = name
+        # we need to be sure that we expanduser() because otherwise a simple
+        # test like .path.exists() will return unexpected results.
+        self.path = name.expanduser()
         # Filename is effective file on disk, for stdin is a namedtempfile
         self.name = self.filename = str(name)
 
@@ -241,12 +251,28 @@ class Lintable:
         self.base_kind = base_kind or kind_from_path(self.path, base=True)
         self.abspath = self.path.expanduser().absolute()
 
+        if self.kind == "tasks":
+            self.parent = _guess_parent(self)
+
         if self.kind == "yaml":
-            self._guess_kind()
+            _ = self.data
+
+    def __del__(self) -> None:
+        """Clean up temporary files when the instance is cleaned up."""
+        if hasattr(self, "file"):
+            self.file.close()
 
     def _guess_kind(self) -> None:
         if self.kind == "yaml":
-            if isinstance(self.data, list) and "hosts" in self.data[0]:
+            if (
+                isinstance(self.data, list)
+                and len(self.data) > 0
+                and (
+                    "hosts" in self.data[0]
+                    or "import_playbook" in self.data[0]
+                    or "ansible.builtin.import_playbook" in self.data[0]
+                )
+            ):
                 if "rules" not in self.data[0]:
                     self.kind = "playbook"
                 else:
@@ -265,7 +291,7 @@ class Lintable:
             return str(self.path)
         if key == "type":
             return str(self.kind)
-        raise NotImplementedError()
+        raise NotImplementedError
 
     def get(self, key: Any, default: Any = None) -> Any:
         """Provide compatibility subscriptable support."""
@@ -276,13 +302,8 @@ class Lintable:
 
     def _populate_content_cache_from_disk(self) -> None:
         # Can raise UnicodeDecodeError
-        try:
-            self._content = self.path.expanduser().resolve().read_text(encoding="utf-8")
-        except FileNotFoundError as ex:
-            if vars(options).get("progressive"):
-                self._content = ""
-            else:
-                raise ex
+        self._content = self.path.expanduser().resolve().read_text(encoding="utf-8")
+
         if self._original_content is None:
             self._original_content = self._content
 
@@ -301,7 +322,8 @@ class Lintable:
         has not already been populated.
         """
         if not isinstance(value, str):
-            raise TypeError(f"Expected str but got {type(value)}")
+            msg = f"Expected str but got {type(value)}"
+            raise TypeError(msg)
         if self._original_content is None:
             if self._content is not None:
                 self._original_content = self._content
@@ -318,7 +340,7 @@ class Lintable:
         """Reset the internal content cache."""
         self._content = None
 
-    def write(self, force: bool = False) -> None:
+    def write(self, *, force: bool = False) -> None:
         """Write the value of ``Lintable.content`` to disk.
 
         This only writes to disk if the content has been updated (``Lintable.updated``).
@@ -336,11 +358,18 @@ class Lintable:
 
             lintable.write(force=True)
         """
-        if not force and not self.updated:
+        dump_filename = self.path.expanduser().resolve()
+        if os.environ.get("ANSIBLE_LINT_WRITE_TMP", "0") == "1":
+            dump_filename = dump_filename.with_suffix(
+                f".tmp{dump_filename.suffix}",
+            )
+        elif not force and not self.updated:
             # No changes to write.
             return
-        self.path.expanduser().resolve().write_text(
-            self._content or "", encoding="utf-8"
+
+        dump_filename.write_text(
+            self._content or "",
+            encoding="utf-8",
         )
 
     def __hash__(self) -> int:
@@ -357,95 +386,72 @@ class Lintable:
         """Return user friendly representation of a lintable."""
         return f"{self.name} ({self.kind})"
 
+    def is_owned_by_ansible(self) -> bool:
+        """Return true for YAML files that are managed by Ansible."""
+        return self.kind in ANSIBLE_OWNED_KINDS
+
     @property
     def data(self) -> Any:
         """Return loaded data representation for current file, if possible."""
-        if self._data == States.NOT_LOADED:
+        if self.state == States.NOT_LOADED:
             if self.path.is_dir():
-                self._data = None
-                return self._data
+                self.state = None
+                return self.state
             try:
                 if str(self.base_kind) == "text/yaml":
                     from ansiblelint.utils import (  # pylint: disable=import-outside-toplevel
                         parse_yaml_linenumbers,
                     )
 
-                    self._data = parse_yaml_linenumbers(self)
+                    self.state = parse_yaml_linenumbers(self)
+                    # now that _data is not empty, we can try guessing if playbook or rulebook
+                    # it has to be done before append_skipped_rules() call as it's relying
+                    # on self.kind.
+                    if self.kind == "yaml":
+                        self._guess_kind()
                     # Lazy import to avoid delays and cyclic-imports
                     if "append_skipped_rules" not in globals():
                         # pylint: disable=import-outside-toplevel
                         from ansiblelint.skip_utils import append_skipped_rules
 
-                    self._data = append_skipped_rules(self._data, self)
+                    self.state = append_skipped_rules(self.state, self)
                 else:
                     logging.debug(
-                        "data set to None for %s due to being of %s kind.",
+                        "data set to None for %s due to being '%s' (%s) kind.",
                         self.path,
-                        self.base_kind,
+                        self.kind,
+                        self.base_kind or "unknown",
                     )
-                    self._data = States.UNKNOWN_DATA
+                    self.state = States.UNKNOWN_DATA
 
-            except (RuntimeError, FileNotFoundError, YAMLError) as exc:
-                self._data = States.LOAD_FAILED
+            except (
+                RuntimeError,
+                FileNotFoundError,
+                YAMLError,
+                UnicodeDecodeError,
+            ) as exc:
+                self.state = States.LOAD_FAILED
                 self.exc = exc
-        return self._data
+        return self.state
 
 
 # pylint: disable=redefined-outer-name
-def discover_lintables(options: Namespace) -> dict[str, Any]:
+def discover_lintables(options: Options) -> list[str]:
     """Find all files that we know how to lint.
 
     Return format is normalized, relative for stuff below cwd, ~/ for content
     under current user and absolute for everything else.
     """
-    # git is preferred as it also considers .gitignore
-    git_command_present = [
-        *GIT_CMD,
-        "ls-files",
-        "--cached",
-        "--others",
-        "--exclude-standard",
-        "-z",
-    ]
-    git_command_absent = [*GIT_CMD, "ls-files", "--deleted", "-z"]
-    out = None
+    if not options.lintables:
+        options.lintables = ["."]
 
-    try:
-        out_present = subprocess.check_output(
-            git_command_present, stderr=subprocess.STDOUT, text=True
-        ).split("\x00")[:-1]
-        _logger.info(
-            "Discovered files to lint using: %s", " ".join(git_command_present)
+    return [
+        str(filename)
+        for filename in get_all_files(
+            *[Path(s) for s in options.lintables],
+            exclude_paths=options.exclude_paths,
         )
-
-        out_absent = subprocess.check_output(
-            git_command_absent, stderr=subprocess.STDOUT, text=True
-        ).split("\x00")[:-1]
-        _logger.info("Excluded removed files using: %s", " ".join(git_command_absent))
-
-        out = set(out_present) - set(out_absent)
-    except subprocess.CalledProcessError as exc:
-        if not (exc.returncode == 128 and "fatal: not a git repository" in exc.output):
-            _logger.warning(
-                "Failed to discover lintable files using git: %s",
-                exc.output.rstrip("\n"),
-            )
-    except FileNotFoundError as exc:
-        if options.verbosity:
-            _logger.warning("Failed to locate command: %s", exc)
-
-    if out is None:
-        exclude_pattern = "|".join(str(x) for x in options.exclude_paths)
-        _logger.info("Looking up for files, excluding %s ...", exclude_pattern)
-        # remove './' prefix from output of WcMatch
-        out = {
-            strip_dotslash_prefix(fname)
-            for fname in WcMatch(
-                ".", exclude_pattern=exclude_pattern, flags=RECURSIVE, limit=256
-            ).match()
-        }
-
-    return OrderedDict.fromkeys(sorted(out))
+    ]
 
 
 def strip_dotslash_prefix(fname: str) -> str:
@@ -453,49 +459,60 @@ def strip_dotslash_prefix(fname: str) -> str:
     return fname[2:] if fname.startswith("./") else fname
 
 
-def guess_project_dir(config_file: str | None) -> str:
-    """Return detected project dir or current working directory."""
-    path = None
-    if config_file is not None and config_file != "/dev/null":
-        target = pathlib.Path(config_file)
-        if target.exists():
-            # for config inside .config, we return the parent dir as project dir
-            cfg_path = target.parent
-            if cfg_path.parts[-1] == ".config":
-                path = str(cfg_path.parent.absolute())
-            else:
-                path = str(cfg_path.absolute())
+def find_project_root(
+    srcs: Sequence[str],
+    config_file: str | None = None,
+) -> tuple[Path, str]:
+    """Return a directory containing .git or ansible-lint config files.
 
-    if path is None:
-        try:
-            result = subprocess.run(
-                [*GIT_CMD, "rev-parse", "--show-toplevel"],
-                capture_output=True,
-                text=True,
-                check=True,
-            )
+    That directory will be a common parent of all files and directories
+    passed in `srcs`.
 
-            path = result.stdout.splitlines()[0]
-        except subprocess.CalledProcessError as exc:
-            if not (
-                exc.returncode == 128 and "fatal: not a git repository" in exc.stderr
-            ):
-                _logger.warning(
-                    "Failed to guess project directory using git: %s",
-                    exc.stderr.rstrip("\n"),
-                )
-        except FileNotFoundError as exc:
-            _logger.warning("Failed to locate command: %s", exc)
+    If no directory in the tree contains a marker that would specify it's the
+    project root, the root of the file system is returned.
 
-    if path is None:
-        path = os.getcwd()
+    Returns a two-tuple with the first element as the project root path and
+    the second element as a string describing the method by which the
+    project root was discovered.
+    """
+    directory = None
+    if not srcs:
+        srcs = [str(Path.cwd().resolve().absolute())]
+    path_srcs = [Path(Path.cwd(), src).resolve() for src in srcs]
 
-    _logger.info(
-        "Guessed %s as project root directory",
-        path,
+    cfg_files = [config_file] if config_file else CONFIG_FILENAMES
+
+    # A list of lists of parents for each 'src'. 'src' is included as a
+    # "parent" of itself if it is a directory
+    src_parents = [
+        list(path.parents) + ([path] if path.is_dir() else []) for path in path_srcs
+    ]
+
+    common_base = max(
+        set.intersection(*(set(parents) for parents in src_parents)),
+        key=lambda path: path.parts,
     )
 
-    return path
+    for directory in (common_base, *common_base.parents):
+        if (directory / ".git").exists():
+            return directory, ".git directory"
+
+        if (directory / ".hg").is_dir():
+            return directory, ".hg directory"
+
+        for cfg_file in cfg_files:
+            # note that if cfg_file is already absolute, 'directory' is ignored
+            resolved_cfg_path = directory / cfg_file
+            if resolved_cfg_path.is_file():
+                if os.path.isabs(cfg_file):
+                    directory = Path(cfg_file).parent
+                    if directory.name == ".config":
+                        directory = directory.parent
+                return directory, f"config file {resolved_cfg_path}"
+
+    if not directory:
+        return Path.cwd(), "current working directory"
+    return directory, "file system root"
 
 
 def expand_dirs_in_lintables(lintables: set[Lintable]) -> None:
@@ -514,5 +531,72 @@ def expand_dirs_in_lintables(lintables: set[Lintable]) -> None:
         for item in copy.copy(lintables):
             if item.path.is_dir():
                 for filename in all_files:
-                    if filename.startswith(str(item.path)):
+                    if filename.startswith((str(item.path), str(item.path.absolute()))):
                         lintables.add(Lintable(filename))
+
+
+def _guess_parent(lintable: Lintable) -> Lintable | None:
+    """Return a parent directory for a lintable."""
+    try:
+        if lintable.path.parents[2].name == "roles":
+            # role_name = lintable.parents[1].name
+            return Lintable(lintable.path.parents[1], kind="role")
+    except IndexError:
+        pass
+    return None
+
+
+def get_all_files(
+    *paths: Path,
+    exclude_paths: list[str] | None = None,
+) -> list[Path]:
+    """Recursively retrieve all files from given folders."""
+    all_files: list[Path] = []
+    exclude_paths = [] if exclude_paths is None else exclude_paths
+
+    def is_excluded(path_to_check: Path) -> bool:
+        """Check if a file is exclude by current specs."""
+        return any(
+            spec.match_file(pathspec.util.append_dir_sep(path_to_check))
+            for spec in pathspecs
+        )
+
+    for path in paths:
+        pathspecs = [
+            pathspec.GitIgnoreSpec.from_lines(
+                [
+                    ".git",
+                    ".tox",
+                    ".mypy_cache",
+                    "__pycache__",
+                    ".DS_Store",
+                    ".coverage",
+                    ".pytest_cache",
+                    ".ruff_cache",
+                    *exclude_paths,
+                ],
+            ),
+        ]
+        gitignore = path / ".gitignore"
+        if gitignore.exists():
+            with gitignore.open(encoding="UTF-8") as f:
+                _logger.info("Loading ignores from %s", gitignore)
+                pathspecs.append(
+                    pathspec.GitIgnoreSpec.from_lines(f.read().splitlines()),
+                )
+
+        # Iterate over all items in the directory
+        if path.is_file():
+            all_files.append(path)
+        else:
+            for item in sorted(path.iterdir()):
+                if is_excluded(item):
+                    _logger.info("Excluded: %s", item)
+                    continue
+                if item.is_file():
+                    all_files.append(item)
+                # If it's a directory, recursively call the function
+                elif item.is_dir():
+                    all_files.extend(get_all_files(item, exclude_paths=exclude_paths))
+
+    return all_files
