@@ -1,22 +1,15 @@
 """Utils to generate rules documentation."""
 import logging
-from pathlib import Path
-from typing import Iterable
+from collections.abc import Iterable
 
 from rich import box
-
-# Remove this compatibility try-catch block once we drop support for rich < 10.7.0
-try:
-    from rich.console import group
-except ImportError:
-    from rich.console import render_group as group  # type: ignore
-
+from rich.console import RenderableType, group
 from rich.markdown import Markdown
 from rich.table import Table
 
 from ansiblelint.config import PROFILES
 from ansiblelint.constants import RULE_DOC_URL
-from ansiblelint.rules import RulesCollection
+from ansiblelint.rules import RulesCollection, TransformMixin
 
 DOC_HEADER = """
 # Default Rules
@@ -30,48 +23,18 @@ Below you can see the list of default rules Ansible Lint use to evaluate playboo
 _logger = logging.getLogger(__name__)
 
 
-def rules_as_docs(rules: RulesCollection) -> str:
-    """Dump documentation files for all rules, returns only confirmation message.
-
-    That is internally used for building documentation and the API can change
-    at any time.
-    """
-    result = ""
-    dump_path = Path(".") / "docs" / "rules"
-    if not dump_path.exists():
-        raise RuntimeError(f"Failed to find {dump_path} folder for dumping rules.")
-
-    with open(dump_path / ".." / "profiles.md", "w", encoding="utf-8") as f:
-        f.write(profiles_as_md(header=True, docs_url="rules/"))
-
-    for rule in rules.alphabetical():
-        result = ""
-        with open(dump_path / f"{rule.id}.md", "w", encoding="utf-8") as f:
-            # because title == rule.id we get the desired labels for free
-            # and we do not have to insert `(target_header)=`
-            title = f"{rule.id}"
-
-            if rule.help:
-                if not rule.help.startswith(f"# {rule.id}"):
-                    raise RuntimeError(
-                        f"Rule {rule.__class__} markdown help does not start with `# {rule.id}` header.\n{rule.help}"
-                    )
-                result = result[1:]
-                result += f"{rule.help}"
-            else:
-                description = rule.description
-                if rule.link:
-                    description += f" [more]({rule.link})"
-
-                result += f"# {title}\n\n**{rule.shortdesc}**\n\n{description}"
-            f.write(result)
-
-    return "All markdown files for rules were dumped!"
-
-
-def rules_as_str(rules: RulesCollection) -> str:
+def rules_as_str(rules: RulesCollection) -> RenderableType:
     """Return rules as string."""
-    return "\n".join([str(rule) for rule in rules.alphabetical()])
+    table = Table(show_header=False, header_style="title", box=box.SIMPLE)
+    for rule in rules.alphabetical():
+        if issubclass(rule.__class__, TransformMixin):
+            rule.tags.insert(0, "autofix")
+        tag = f"[dim] ({', '.join(rule.tags)})[/dim]" if rule.tags else ""
+        table.add_row(
+            f"[link={RULE_DOC_URL}{rule.id}/]{rule.id}[/link]",
+            rule.shortdesc + tag,
+        )
+    return table
 
 
 def rules_as_md(rules: RulesCollection) -> str:
@@ -79,16 +42,14 @@ def rules_as_md(rules: RulesCollection) -> str:
     result = DOC_HEADER
 
     for rule in rules.alphabetical():
-
         # because title == rule.id we get the desired labels for free
         # and we do not have to insert `(target_header)=`
         title = f"{rule.id}"
 
         if rule.help:
-            if not rule.help.startswith(f"# {rule.id}"):
-                raise RuntimeError(
-                    f"Rule {rule.__class__} markdown help does not start with `# {rule.id}` header.\n{rule.help}"
-                )
+            if not rule.help.startswith(f"# {rule.id}"):  # pragma: no cover
+                msg = f"Rule {rule.__class__} markdown help does not start with `# {rule.id}` header.\n{rule.help}"
+                raise RuntimeError(msg)
             result += f"\n\n{rule.help}"
         else:
             description = rule.description
@@ -97,6 +58,12 @@ def rules_as_md(rules: RulesCollection) -> str:
 
             result += f"\n\n## {title}\n\n**{rule.shortdesc}**\n\n{description}"
 
+        # Safety net for preventing us from adding autofix to rules and
+        # forgetting to mention it inside their documentation.
+        if "autofix" in rule.tags and "autofix" not in rule.description:
+            msg = f"Rule {rule.id} is invalid because it has 'autofix' tag but this ability is not documented in its description."
+            raise RuntimeError(msg)
+
     return result
 
 
@@ -122,7 +89,7 @@ def rules_as_rich(rules: RulesCollection) -> Iterable[Table]:
         yield table
 
 
-def profiles_as_md(header: bool = False, docs_url: str = RULE_DOC_URL) -> str:
+def profiles_as_md(*, header: bool = False, docs_url: str = RULE_DOC_URL) -> str:
     """Return markdown representation of supported profiles."""
     result = ""
 
@@ -134,9 +101,9 @@ Do not manually edit, generated from generate_docs.py
 
 Ansible-lint profiles gradually increase the strictness of rules as your Ansible content lifecycle.
 
-```{note}
-Rules with `*` in the suffix are not yet implemented but are documented with linked GitHub issues.
-```
+!!! note
+
+    Rules with `*` in the suffix are not yet implemented but are documented with linked GitHub issues.
 
 """
 
