@@ -6,15 +6,14 @@ from __future__ import annotations
 
 import re
 import sys
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING
 
 from ansiblelint.rules import AnsibleLintRule
 from ansiblelint.yaml_utils import nested_items_path
 
 if TYPE_CHECKING:
-    from typing import Optional
-
     from ansiblelint.file_utils import Lintable
+    from ansiblelint.utils import Task
 
 
 class ComparisonToEmptyStringRule(AnsibleLintRule):
@@ -32,7 +31,9 @@ class ComparisonToEmptyStringRule(AnsibleLintRule):
     empty_string_compare = re.compile("[=!]= ?(\"{2}|'{2})")
 
     def matchtask(
-        self, task: dict[str, Any], file: Lintable | None = None
+        self,
+        task: Task,
+        file: Lintable | None = None,
     ) -> bool | str:
         for k, v, _ in nested_items_path(task):
             if k == "when":
@@ -44,7 +45,7 @@ class ComparisonToEmptyStringRule(AnsibleLintRule):
                 else:
                     for item in v:
                         if isinstance(item, str) and self.empty_string_compare.search(
-                            item
+                            item,
                         ):
                             return True
 
@@ -53,46 +54,27 @@ class ComparisonToEmptyStringRule(AnsibleLintRule):
 
 # testing code to be loaded only with pytest or when executed the rule file
 if "pytest" in sys.modules:
+    from ansiblelint.rules import RulesCollection
+    from ansiblelint.runner import Runner
 
-    import pytest
-
-    from ansiblelint.testing import RunFromText  # pylint: disable=ungrouped-imports
-
-    SUCCESS_PLAY = """
-- hosts: all
-  tasks:
-    - name: Shut down
-      shell: |
-        /sbin/shutdown -t now
-        echo $var == ""
-      when: ansible_os_family
-"""
-
-    FAIL_PLAY = """
-- hosts: all
-  tasks:
-  - name: Shut down
-    command: /sbin/shutdown -t now
-    when: ansible_os_family == ""
-  - name: Shut down
-    command: /sbin/shutdown -t now
-    when: ansible_os_family !=""
-"""
-
-    @pytest.mark.parametrize(
-        "rule_runner", (ComparisonToEmptyStringRule,), indirect=["rule_runner"]
-    )
-    def test_rule_empty_string_compare_fail(rule_runner: RunFromText) -> None:
+    def test_rule_empty_string_compare_fail() -> None:
         """Test rule matches."""
-        results = rule_runner.run_playbook(FAIL_PLAY)
-        assert len(results) == 2
+        rules = RulesCollection()
+        rules.register(ComparisonToEmptyStringRule())
+        results = Runner(
+            "examples/playbooks/rule-empty-string-compare-fail.yml",
+            rules=rules,
+        ).run()
+        assert len(results) == 3
         for result in results:
             assert result.message == ComparisonToEmptyStringRule().shortdesc
 
-    @pytest.mark.parametrize(
-        "rule_runner", (ComparisonToEmptyStringRule,), indirect=["rule_runner"]
-    )
-    def test_rule_empty_string_compare_pass(rule_runner: RunFromText) -> None:
+    def test_rule_empty_string_compare_pass() -> None:
         """Test rule matches."""
-        results = rule_runner.run_playbook(SUCCESS_PLAY)
+        rules = RulesCollection()
+        rules.register(ComparisonToEmptyStringRule())
+        results = Runner(
+            "examples/playbooks/rule-empty-string-compare-pass.yml",
+            rules=rules,
+        ).run()
         assert len(results) == 0, results
