@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import logging
+import os
 import re
 import sys
 from dataclasses import dataclass
@@ -18,6 +19,7 @@ from ansiblelint.constants import LINE_NUMBER_KEY
 from ansiblelint.errors import RuleMatchTransformMeta
 from ansiblelint.file_utils import Lintable
 from ansiblelint.rules import AnsibleLintRule, TransformMixin
+from ansiblelint.runner import get_matches
 from ansiblelint.skip_utils import get_rule_skips_from_line
 from ansiblelint.text import has_jinja
 from ansiblelint.utils import parse_yaml_from_file, template
@@ -26,6 +28,7 @@ from ansiblelint.yaml_utils import deannotate, nested_items_path
 if TYPE_CHECKING:
     from ruamel.yaml.comments import CommentedMap, CommentedSeq
 
+    from ansiblelint.config import Options
     from ansiblelint.errors import MatchError
     from ansiblelint.utils import Task
 
@@ -141,7 +144,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                         )
                         if ignored_re.search(orig_exc_message) or isinstance(
                             orig_exc,
-                            AnsibleParserError,
+                            (AnsibleParserError, TypeError),
                         ):
                             # An unhandled exception occurred while running the lookup plugin 'template'. Error was a <class 'ansible.errors.AnsibleError'>, original message: the template file ... could not be found for the lookup. the template file ... could not be found for the lookup
 
@@ -217,7 +220,6 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
 
         if str(file.kind) == "vars":
             data = parse_yaml_from_file(str(file.path))
-            # pylint: disable=unused-variable
             for key, v, _path in nested_items_path(data):
                 if isinstance(v, AnsibleUnicode):
                     reformatted, details, tag = self.check_whitespace(
@@ -285,7 +287,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             last_value = value
         return result
 
-    # pylint: disable=too-many-statements,too-many-locals
+    # pylint: disable=too-many-locals
     def check_whitespace(
         self,
         text: str,
@@ -384,8 +386,6 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
 
         except jinja2.exceptions.TemplateSyntaxError as exc:
             return "", str(exc.message), "invalid"
-        # https://github.com/PyCQA/pylint/issues/7433 - py311 only
-        # pylint: disable=c-extension-no-member
         except (NotImplementedError, black.parsing.InvalidInput) as exc:
             # black is not able to recognize all valid jinja2 templates, so we
             # just ignore InvalidInput errors.
@@ -450,6 +450,8 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             ignored_keys=ignored_keys,
         ):
             if key == match.transform_meta.key and value == match.transform_meta.value:
+                if not path:
+                    continue
                 for pth in path[:-1]:
                     try:
                         obj = obj[pth]
@@ -476,10 +478,14 @@ def blacken(text: str) -> str:
 
 
 if "pytest" in sys.modules:
+    from unittest import mock
+
     import pytest
 
-    from ansiblelint.rules import RulesCollection  # pylint: disable=ungrouped-imports
-    from ansiblelint.runner import Runner  # pylint: disable=ungrouped-imports
+    # pylint: disable=ungrouped-imports
+    from ansiblelint.rules import RulesCollection
+    from ansiblelint.runner import Runner
+    from ansiblelint.transformer import Transformer
 
     @pytest.fixture(name="error_expected_lines")
     def fixture_error_expected_lines() -> list[int]:
@@ -821,6 +827,38 @@ if "pytest" in sys.modules:
         errs = Runner(success, rules=collection).run()
         assert len(errs) == 0
 
+    @mock.patch.dict(os.environ, {"ANSIBLE_LINT_WRITE_TMP": "1"}, clear=True)
+    def test_jinja_transform(
+        config_options: Options,
+        default_rules_collection: RulesCollection,
+    ) -> None:
+        """Test transform functionality for jinja rule."""
+        playbook = Path("examples/playbooks/rule-jinja-before.yml")
+        config_options.write_list = ["all"]
+
+        config_options.lintables = [str(playbook)]
+        runner_result = get_matches(
+            rules=default_rules_collection,
+            options=config_options,
+        )
+        transformer = Transformer(result=runner_result, options=config_options)
+        transformer.run()
+
+        matches = runner_result.matches
+        assert len(matches) == 2
+
+        orig_content = playbook.read_text(encoding="utf-8")
+        expected_content = playbook.with_suffix(
+            f".transformed{playbook.suffix}",
+        ).read_text(encoding="utf-8")
+        transformed_content = playbook.with_suffix(f".tmp{playbook.suffix}").read_text(
+            encoding="utf-8",
+        )
+
+        assert orig_content != transformed_content
+        assert expected_content == transformed_content
+        playbook.with_suffix(f".tmp{playbook.suffix}").unlink()
+
 
 def _get_error_line(task: dict[str, Any], path: list[str | int]) -> int:
     """Return error line number."""
