@@ -1,16 +1,17 @@
 """Implementation of meta-video-links rule."""
 # Copyright (c) 2018, Ansible Project
+from __future__ import annotations
 
 import re
-from typing import TYPE_CHECKING, List
+import sys
+from typing import TYPE_CHECKING
 
+from ansiblelint.constants import FILENAME_KEY, LINE_NUMBER_KEY
 from ansiblelint.rules import AnsibleLintRule
-from ansiblelint.utils import FILENAME_KEY, LINE_NUMBER_KEY
 
 if TYPE_CHECKING:
-    from typing import Any
+    from collections.abc import Sequence
 
-    from ansiblelint.constants import odict
     from ansiblelint.errors import MatchError
     from ansiblelint.file_utils import Lintable
 
@@ -34,13 +35,11 @@ class MetaVideoLinksRule(AnsibleLintRule):
         "youtube": re.compile(r"https://youtu\.be/([0-9A-Za-z-_]+)"),
     }
 
-    def matchplay(
-        self, file: "Lintable", data: "odict[str, Any]"
-    ) -> List["MatchError"]:
-        if file.kind != "meta":
+    def matchyaml(self, file: Lintable) -> list[MatchError]:
+        if file.kind != "meta" or not file.data:
             return []
 
-        galaxy_info = data.get("galaxy_info", None)
+        galaxy_info = file.data.get("galaxy_info", None)
         if not galaxy_info:
             return []
 
@@ -56,7 +55,7 @@ class MetaVideoLinksRule(AnsibleLintRule):
                     self.create_matcherror(
                         "Expected item in 'video_links' to be a dictionary",
                         filename=file,
-                    )
+                    ),
                 )
                 continue
 
@@ -66,11 +65,11 @@ class MetaVideoLinksRule(AnsibleLintRule):
                         "Expected item in 'video_links' to contain "
                         "only keys 'url' and 'title'",
                         filename=file,
-                    )
+                    ),
                 )
                 continue
 
-            for _, expr in self.VIDEO_REGEXP.items():
+            for expr in self.VIDEO_REGEXP.values():
                 if expr.match(video["url"]):
                     break
             else:
@@ -82,3 +81,43 @@ class MetaVideoLinksRule(AnsibleLintRule):
                 results.append(self.create_matcherror(msg, filename=file))
 
         return results
+
+
+if "pytest" in sys.modules:
+    import pytest
+
+    # pylint: disable=ungrouped-imports
+    from ansiblelint.rules import RulesCollection
+    from ansiblelint.runner import Runner
+
+    @pytest.mark.parametrize(
+        ("test_file", "failures"),
+        (
+            pytest.param(
+                "examples/roles/meta_video_links_fail/meta/main.yml",
+                (
+                    "Expected item in 'video_links' to be a dictionary",
+                    "Expected item in 'video_links' to contain only keys 'url' and 'title'",
+                    "URL format 'https://www.youtube.com/watch?v=aWmRepTSFKs&feature=youtu.be' is not recognized. Expected it be a shared link from Vimeo, YouTube, or Google Drive.",
+                    "URL format 'www.acme.com/vid' is not recognized",
+                ),
+                id="1",
+            ),
+            pytest.param(
+                "examples/roles/meta_video_links_pass/meta/main.yml",
+                (),
+                id="2",
+            ),
+        ),
+    )
+    def test_video_links(
+        default_rules_collection: RulesCollection,
+        test_file: str,
+        failures: Sequence[str],
+    ) -> None:
+        """Test rule matches."""
+        results = Runner(test_file, rules=default_rules_collection).run()
+        assert len(results) == len(failures)
+        for index, result in enumerate(results):
+            assert result.tag == "meta-video-links"
+            assert failures[index] in result.message
