@@ -11,6 +11,7 @@ from ansiblelint.rules import AnsibleLintRule
 
 if TYPE_CHECKING:
     from ansiblelint.file_utils import Lintable
+    from ansiblelint.utils import Task
 
 
 class NoSameOwnerRule(AnsibleLintRule):
@@ -26,7 +27,9 @@ should not be preserved when transferring files between them.
     tags = ["opt-in"]
 
     def matchtask(
-        self, task: dict[str, Any], file: Lintable | None = None
+        self,
+        task: Task,
+        file: Lintable | None = None,
     ) -> bool | str:
         """Return matches for a task."""
         action = task.get("action")
@@ -67,12 +70,13 @@ should not be preserved when transferring files between them.
             if not isinstance(src, str):
                 return False
 
-            if src.endswith("zip"):
-                if "-X" in action.get("extra_opts", []):
-                    return True
-            if re.search(r".*\.tar(\.(gz|bz2|xz))?$", src):
-                if "--no-same-owner" not in action.get("extra_opts", []):
-                    return True
+            if src.endswith("zip") and "-X" in action.get("extra_opts", []):
+                return True
+            if re.search(
+                r".*\.tar(\.(gz|bz2|xz))?$",
+                src,
+            ) and "--no-same-owner" not in action.get("extra_opts", []):
+                return True
         return False
 
 
@@ -80,22 +84,29 @@ should not be preserved when transferring files between them.
 if "pytest" in sys.modules:
     import pytest
 
-    from ansiblelint.rules import RulesCollection  # pylint: disable=ungrouped-imports
-    from ansiblelint.runner import Runner  # pylint: disable=ungrouped-imports
+    # pylint: disable=ungrouped-imports
+    from ansiblelint.rules import RulesCollection
+    from ansiblelint.runner import Runner
 
     @pytest.mark.parametrize(
         ("test_file", "failures"),
         (
             pytest.param(
-                "examples/roles/role_for_no_same_owner/tasks/fail.yml", 12, id="fail"
+                "examples/roles/role_for_no_same_owner/tasks/fail.yml",
+                12,
+                id="fail",
             ),
             pytest.param(
-                "examples/roles/role_for_no_same_owner/tasks/pass.yml", 0, id="pass"
+                "examples/roles/role_for_no_same_owner/tasks/pass.yml",
+                0,
+                id="pass",
             ),
         ),
     )
     def test_no_same_owner_rule(
-        default_rules_collection: RulesCollection, test_file: str, failures: int
+        default_rules_collection: RulesCollection,
+        test_file: str,
+        failures: int,
     ) -> None:
         """Test rule matches."""
         results = Runner(test_file, rules=default_rules_collection).run()
